Class: Girb::Tools::ContinueAnalysis

Inherits:
Base
  • Object
show all
Defined in:
lib/girb/tools/continue_analysis.rb

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Base

to_gemini_tool, tool_name

Class Method Details

.available?Boolean

Returns:

  • (Boolean)


29
30
31
32
# File 'lib/girb/tools/continue_analysis.rb', line 29

def available?
  # In debug mode, use run_debug_command with auto_continue instead
  !defined?(DEBUGGER__)
end

.descriptionObject



9
10
11
12
13
14
# File 'lib/girb/tools/continue_analysis.rb', line 9

def description
  "Request to be re-invoked with a refreshed context (updated local variables, " \
  "instance variables, last value, etc.). Use this after executing code that " \
  "changes state, when you need to see the full updated picture before deciding " \
  "your next action."
end

.parametersObject



16
17
18
19
20
21
22
23
24
25
26
27
# File 'lib/girb/tools/continue_analysis.rb', line 16

def parameters
  {
    type: "object",
    properties: {
      reason: {
        type: "string",
        description: "Brief description of why you need a context refresh and what you plan to check next."
      }
    },
    required: ["reason"]
  }
end

Instance Method Details

#execute(binding, reason:) ⇒ Object



35
36
37
38
39
40
41
42
# File 'lib/girb/tools/continue_analysis.rb', line 35

def execute(binding, reason:)
  Girb::AutoContinue.request!
  {
    success: true,
    message: "You will be re-invoked with updated context after this response.",
    reason: reason
  }
end